@@ -263,18 +263,18 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_imagebuilder
-import constructs
+import aws_cdk.aws_imagebuilder as _aws_cdk_aws_imagebuilder_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ImagePipeline(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-image-pipeline.ImagePipeline",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         component_documents: typing.Sequence[builtins.str],
@@ -313,28 +313,7 @@ class ImagePipeline(
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                component_documents: typing.Sequence[builtins.str],
-                component_names: typing.Sequence[builtins.str],
-                component_versions: typing.Sequence[builtins.str],
-                image_recipe: builtins.str,
-                infra_config_name: builtins.str,
-                kms_key_alias: builtins.str,
-                parent_image: builtins.str,
-                pipeline_name: builtins.str,
-                profile_name: builtins.str,
-                email: typing.Optional[builtins.str] = None,
-                image_recipe_version: typing.Optional[builtins.str] = None,
-                instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
-                platform: typing.Optional[builtins.str] = None,
-                security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
-                subnet_id: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571aeb5620d4)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ImagePipelineProps(
@@ -361,20 +340,16 @@ class ImagePipeline(
     @jsii.member(jsii_name="imageRecipeComponents")
     def image_recipe_components(
         self,
-    ) -> typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty]:
-        return typing.cast(typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty], jsii.get(self, "imageRecipeComponents"))
+    ) -> typing.List[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.ComponentConfigurationProperty]:
+        return typing.cast(typing.List[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.ComponentConfigurationProperty], jsii.get(self, "imageRecipeComponents"))
 
     @image_recipe_components.setter
     def image_recipe_components(
         self,
-        value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
+        value: typing.List[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.ComponentConfigurationProperty],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f6030b5c4ec4934f0e7f5cd5e6d6b3950a65ad587993a25e55770d3d1d32b91e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageRecipeComponents", value)
 
@@ -438,26 +413,7 @@ class ImagePipelineProps:
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         if __debug__:
-            def stub(
-                *,
-                component_documents: typing.Sequence[builtins.str],
-                component_names: typing.Sequence[builtins.str],
-                component_versions: typing.Sequence[builtins.str],
-                image_recipe: builtins.str,
-                infra_config_name: builtins.str,
-                kms_key_alias: builtins.str,
-                parent_image: builtins.str,
-                pipeline_name: builtins.str,
-                profile_name: builtins.str,
-                email: typing.Optional[builtins.str] = None,
-                image_recipe_version: typing.Optional[builtins.str] = None,
-                instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
-                platform: typing.Optional[builtins.str] = None,
-                security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
-                subnet_id: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edbdff4c88)
             check_type(argname="argument component_documents", value=component_documents, expected_type=type_hints["component_documents"])
             check_type(argname="argument component_names", value=component_names, expected_type=type_hints["component_names"])
             check_type(argname="argument component_versions", value=component_versions, expected_type=type_hints["component_versions"])
@@ -473,7 +429,7 @@ class ImagePipelineProps:
             check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
             check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
             check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "component_documents": component_documents,
             "component_names": component_names,
             "component_versions": component_versions,
@@ -620,3 +576,53 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571aeb5620d4(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    component_documents: typing.Sequence[builtins.str],
+    component_names: typing.Sequence[builtins.str],
+    component_versions: typing.Sequence[builtins.str],
+    image_recipe: builtins.str,
+    infra_config_name: builtins.str,
+    kms_key_alias: builtins.str,
+    parent_image: builtins.str,
+    pipeline_name: builtins.str,
+    profile_name: builtins.str,
+    email: typing.Optional[builtins.str] = None,
+    image_recipe_version: typing.Optional[builtins.str] = None,
+    instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
+    platform: typing.Optional[builtins.str] = None,
+    security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f6030b5c4ec4934f0e7f5cd5e6d6b3950a65ad587993a25e55770d3d1d32b91e(
+    value: typing.List[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.ComponentConfigurationProperty],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edbdff4c88(
+    *,
+    component_documents: typing.Sequence[builtins.str],
+    component_names: typing.Sequence[builtins.str],
+    component_versions: typing.Sequence[builtins.str],
+    image_recipe: builtins.str,
+    infra_config_name: builtins.str,
+    kms_key_alias: builtins.str,
+    parent_image: builtins.str,
+    pipeline_name: builtins.str,
+    profile_name: builtins.str,
+    email: typing.Optional[builtins.str] = None,
+    image_recipe_version: typing.Optional[builtins.str] = None,
+    instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
+    platform: typing.Optional[builtins.str] = None,
+    security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
